@@ -1,4 +1,4 @@
-/* $Id: procargs.h,v 1.15 2003/10/19 16:10:17 carlos Exp $ */
+/* $Id: procargs.h,v 1.17 2003/10/20 20:11:58 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_PROC_ARGS_SIZE		0
 
@@ -37,7 +37,7 @@ typedef struct _glibtop_proc_args	glibtop_proc_args;
 
 struct _glibtop_proc_args
 {
-	u_int64_t	flags,
+	guint64	flags,
 		size;			/* GLIBTOP_PROC_ARGS_SIZE	*/
 };
 
@@ -78,6 +78,6 @@ extern const char *glibtop_descriptions_proc_args [];
 
 #endif
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
