@@ -1,4 +1,4 @@
-/* $Id: prockernel.h,v 1.14 1999/02/23 11:43:04 martin Exp $ */
+/* $Id: prockernel.h,v 1.24 2003/10/20 20:11:58 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_PROC_KERNEL_K_FLAGS	0
 #define GLIBTOP_PROC_KERNEL_MIN_FLT	1
@@ -47,8 +47,8 @@ typedef struct _glibtop_proc_kernel	glibtop_proc_kernel;
 
 struct _glibtop_proc_kernel
 {
-	u_int64_t flags;
-	u_int64_t k_flags,	/* kernel flags for the process */
+	guint64 flags;
+	guint64 k_flags,	/* kernel flags for the process */
 		min_flt,	/* number of minor page faults since
 				 * process start */
 		maj_flt,	/* number of major page faults since
@@ -93,6 +93,6 @@ extern const char *glibtop_descriptions_proc_kernel [];
 
 #endif
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
