@@ -1,4 +1,4 @@
-/* $Id: swap.h,v 1.21 2003/10/19 16:10:17 carlos Exp $ */
+/* $Id: swap.h,v 1.23 2003/10/20 20:11:58 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_SWAP_TOTAL	0
 #define GLIBTOP_SWAP_USED	1
@@ -41,7 +41,7 @@ typedef struct _glibtop_swap	glibtop_swap;
 
 struct _glibtop_swap
 {
-	u_int64_t	flags,
+	guint64	flags,
 		total,		/* GLIBTOP_SWAP_TOTAL	*/
 		used,		/* GLIBTOP_SWAP_USED	*/
 		free,		/* GLIBTOP_SWAP_FREE	*/
@@ -78,6 +78,6 @@ extern const char *glibtop_descriptions_swap [];
 
 #endif
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
