@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: sysinfo.h,v 1.11 2003/10/20 20:11:58 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -32,7 +30,7 @@
 
 #include <glib.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_SYSINFO_CPUINFO		0
 
@@ -44,15 +42,15 @@ typedef struct _glibtop_entry	glibtop_entry;
 
 struct _glibtop_entry
 {
-    GPtrArray	*labels;
-    GHashTable	*values;
-    GHashTable	*descriptions;
+	GPtrArray	*labels;
+	GHashTable	*values;
+	GHashTable	*descriptions;
 };
 
 struct _glibtop_sysinfo
 {
-    u_int64_t		flags, ncpu;
-    glibtop_entry	cpuinfo [GLIBTOP_NCPU];
+	guint64	flags, ncpu;
+	glibtop_entry	cpuinfo [GLIBTOP_NCPU];
 };
 
 #define glibtop_get_sysinfo()	glibtop_get_sysinfo_s(glibtop_global_server)
@@ -61,6 +59,6 @@ struct _glibtop_sysinfo
 
 glibtop_sysinfo *glibtop_get_sysinfo_s (glibtop *server);
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
