@@ -1,4 +1,4 @@
-/* $Id: read_data.c,v 1.8 1999/02/23 11:43:37 martin Exp $ */
+/* $Id: read_data.c,v 1.16 2004/03/04 15:29:12 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,8 +21,10 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <glibtop/xmalloc.h>
+#include <config.h>
+
 #include <glibtop/read_data.h>
+#include "libgtop-i18n.h"
 
 /* Reads some data from server. */
 
@@ -54,7 +56,7 @@ glibtop_read_data_l (glibtop *server)
 
 	if (!size) return NULL;	
 
-	ptr = glibtop_malloc_r (server, size);
+	ptr = g_malloc (size);
 	
 	if (server->socket) {
 		ret = recv (server->socket, ptr, size, 0);
@@ -63,7 +65,7 @@ glibtop_read_data_l (glibtop *server)
 	}
 
 	if (ret < 0)
-		glibtop_error_io_r (server, _("read data %d bytes"));
+		glibtop_error_io_r (server, ngettext ("read data %d byte", "read data %d bytes", size));
 
 	return ptr;
 }
