@@ -1,4 +1,4 @@
-/* $Id: glibtop_suid.h,v 1.1.2.1 2002/12/30 16:15:12 hadess Exp $ */
+/* $Id: glibtop_suid.h,v 1.3 2003/10/20 15:19:46 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -24,7 +24,7 @@
 #ifndef __GLIBTOP_SUID_H__
 #define __GLIBTOP_SUID_H__
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #if _IN_LIBGTOP
 #include <sys/param.h>
@@ -47,6 +47,6 @@ glibtop_open_p (glibtop *server, const char *program_name,
 		const unsigned long features,
 		const unsigned flags);
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
