@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: uptime.c,v 1.13 2004/03/09 23:13:31 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -40,40 +38,58 @@ static const unsigned long _required_cpu_flags =
 
 /* Init function. */
 
-int
+void
 glibtop_init_uptime_p (glibtop *server)
 {
-    server->sysdeps.uptime = _glibtop_sysdeps_uptime;
-
-    return 0;
+	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
 }
 
 /* Provides uptime and idle time. */
 
-int
+void
 glibtop_get_uptime_p (glibtop *server, glibtop_uptime *buf)
 {
-    glibtop_cpu cpu;
+#ifdef __NetBSD__
+	time_t now;
+	time_t uptime;
+	int mib[2];
+	struct timeval boottime;
+	size_t size;
 
-    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_UPTIME), 0);
+	mib[0] = CTL_KERN;
+	mib[1] = KERN_BOOTTIME;
+	size = sizeof(boottime);
+	if (sysctl(mib, 2, &boottime, &size, NULL, 0) != -1 &&
+	    boottime.tv_sec != 0) {
+		time(&now);
+		buf->uptime = now - boottime.tv_sec;
+		/* XXX: don't know a useful value to put here. */
+		buf->idletime = 0;
+		buf->flags = _glibtop_sysdeps_uptime;
+	}
+#else
+	buf->flags = _glibtop_sysdeps_uptime;
+
+	glibtop_cpu cpu;
+
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_UPTIME), 0);
 	
-    memset (buf, 0, sizeof (glibtop_uptime));
+	memset (buf, 0, sizeof (glibtop_uptime));
 
-    /* We simply calculate it from the CPU usage. */
+	/* We simply calculate it from the CPU usage. */
 
-    glibtop_get_cpu_p (server, &cpu);
+	glibtop_get_cpu_p (server, &cpu);
 
-    /* Make sure all required fields are present. */
+	/* Make sure all required fields are present. */
 
-    if ((cpu.flags & _required_cpu_flags) != _required_cpu_flags)
-	return -1;
+	if ((cpu.flags & _required_cpu_flags) != _required_cpu_flags)
+		return;
 
-    /* Calculate values. */
+	/* Calculate values. */
 
-    buf->uptime = (double) cpu.total / (double) cpu.frequency;
-    buf->idletime = (double) cpu.idle / (double) cpu.frequency;
+	buf->uptime = (double) cpu.total / (double) cpu.frequency;
+	buf->idletime = (double) cpu.idle / (double) cpu.frequency;
 
-    buf->flags = _glibtop_sysdeps_uptime;
-
-    return 0;
+	buf->flags = _glibtop_sysdeps_uptime;
+#endif
 }
