@@ -1,11 +1,9 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: shm_limits.c,v 1.16 2003/10/19 16:55:36 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
-   Contributed by Martin Baulig <martin@home-of-linux.org>, March 1999.
+   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
 
    LibGTop is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
@@ -29,41 +27,36 @@
 #include <sys/shm.h>
 
 static unsigned long _glibtop_sysdeps_shm_limits =
-(1L << GLIBTOP_SHM_LIMITS_SHMMAX) + (1L << GLIBTOP_SHM_LIMITS_SHMMIN) +
-(1L << GLIBTOP_SHM_LIMITS_SHMMNI) + (1L << GLIBTOP_SHM_LIMITS_SHMSEG) +
-(1L << GLIBTOP_SHM_LIMITS_SHMALL);
+(1 << GLIBTOP_IPC_SHMMAX) + (1 << GLIBTOP_IPC_SHMMIN) +
+(1 << GLIBTOP_IPC_SHMMNI) + (1 << GLIBTOP_IPC_SHMSEG) +
+(1 << GLIBTOP_IPC_SHMALL);
 
 /* Init function. */
 
-int
+void
 glibtop_init_shm_limits_s (glibtop *server)
 {
-    server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
-
-    return 0;
+	server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
 }
 
 /* Provides information about sysv ipc limits. */
 
-int
+void
 glibtop_get_shm_limits_s (glibtop *server, glibtop_shm_limits *buf)
 {
-    struct shminfo shminfo;
+	struct shminfo	shminfo;
   
-    glibtop_init_s (&server, GLIBTOP_SYSDEPS_SHM_LIMITS, 0);
+	glibtop_init_s (&server, GLIBTOP_SYSDEPS_SHM_LIMITS, 0);
 
-    memset (buf, 0, sizeof (glibtop_shm_limits));
+	memset (buf, 0, sizeof (glibtop_shm_limits));
   
-    buf->flags = _glibtop_sysdeps_shm_limits;
+	buf->flags = _glibtop_sysdeps_shm_limits;
   
-    if (shmctl (0, IPC_INFO, (struct shmid_ds *) &shminfo))
-	return -1;
+	shmctl (0, IPC_INFO, (struct shmid_ds *) &shminfo);
   
-    buf->shmmax = shminfo.shmmax;
-    buf->shmmin = shminfo.shmmin;
-    buf->shmmni = shminfo.shmmni;
-    buf->shmseg = shminfo.shmseg;
-    buf->shmall = shminfo.shmall;
-
-    return 0;
+	buf->shmmax = shminfo.shmmax;
+	buf->shmmin = shminfo.shmmin;
+	buf->shmmni = shminfo.shmmni;
+	buf->shmseg = shminfo.shmseg;
+	buf->shmall = shminfo.shmall;
 }
