@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: glibtop_server.h,v 1.18 2003/12/23 10:44:33 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -29,84 +27,103 @@
 #include <fcntl.h>
 #include <ctype.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #ifdef _IN_LIBGTOP
 
 static inline char *
 skip_token (const char *p)
 {
-    while (isspace(*p)) p++;
-    while (*p && !isspace(*p)) p++;
-    return (char *)p;
+        while (isspace(*p)) p++;
+        while (*p && !isspace(*p)) p++;
+	return (char *)p;
 }
 
 static inline char *
 skip_multiple_token (const char *p, int count)
 {
-    int i;
+	int i;
 
-    for (i = 0; i < count; i++)
-	p = skip_token (p);
+	for (i = 0; i < count; i++)
+		p = skip_token (p);
 
-    return (char *)p;
+	return (char *)p;
 }
 
 static inline char *
 skip_line (const char *p)
 {
-    while (*p != '\n') p++;
-    return (char *) ++p;
+	while (*p != '\n') p++;
+	return (char *) ++p;
+}
+
+static inline unsigned long long
+get_scaled(const char *buffer, const char *key)
+{
+  const char    *ptr;
+  char          *next;
+  unsigned long long value = 0;
+  
+  if ((ptr = strstr(buffer, key)))
+    {
+      ptr += strlen(key);
+      value = strtoull(ptr, &next, 0);
+      if (strchr(next, 'k'))
+	value *= 1024;
+      else if (strchr(next, 'M'))
+	value *= 1024 * 1024;
+    }
+  return value;
 }
 
 static inline int
 proc_file_to_buffer (char *buffer, const char *fmt, pid_t pid)
 {
-    char filename [BUFSIZ];
-    int fd, len;
+	char filename [BUFSIZ];
+	int fd, len;
 
-    sprintf (filename, fmt, pid);
+	sprintf (filename, fmt, pid);
 
-    fd = open (filename, O_RDONLY);
-    if (fd < 0) return -1;
+	fd = open (filename, O_RDONLY);
+	if (fd < 0) return -1;
 
-    len = read (fd, buffer, BUFSIZ-1);
-    close (fd);
+	len = read (fd, buffer, BUFSIZ-1);
+	close (fd);
 
-    if (len < 0)
-	return -1;
+	if (len < 0)
+	    return -1;
 
-    buffer [len] = '\0';
+	buffer [len] = '\0';
 
-    return 0;
+	return 0;
 }
 
 static inline int
 proc_stat_to_buffer (char *buffer, pid_t pid)
 {
-    return proc_file_to_buffer (buffer, "/proc/%d/stat", pid);
+	return proc_file_to_buffer (buffer, "/proc/%d/stat", pid);
 }
 
 static inline int
 proc_status_to_buffer (char *buffer, pid_t pid)
 {
-    return proc_file_to_buffer (buffer, "/proc/%d/status", pid);
+	return proc_file_to_buffer (buffer, "/proc/%d/status", pid);
 }
 
 static inline int
 proc_statm_to_buffer (char *buffer, pid_t pid)
 {
-    return proc_file_to_buffer (buffer, "/proc/%d/statm", pid);
+	return proc_file_to_buffer (buffer, "/proc/%d/statm", pid);
 }
 
 static inline char *
 proc_stat_after_cmd (char *p)
 {
-    p = strrchr (p, ')');
-    if (!p) return p;
+	p = strrchr (p, ')');
+	if (!p) return p;
 
-    *p++ = '\0';
-    return p;
+	*p++ = '\0';
+	return p;
 }
 
 #endif
@@ -129,11 +146,9 @@ proc_stat_after_cmd (char *p)
 #define GLIBTOP_SUID_PROC_SEGMENT	0
 #define GLIBTOP_SUID_PROC_ARGS		0
 #define GLIBTOP_SUID_PROC_MAP		0
-#define GLIBTOP_SUID_NETINFO		0
 #define GLIBTOP_SUID_NETLOAD		0
-#define GLIBTOP_SUID_INTERFACE_NAMES	0
 #define GLIBTOP_SUID_PPP		0
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
