@@ -1,4 +1,4 @@
-/* $Id: procuid.c,v 1.8 2003/10/19 16:10:39 carlos Exp $ */
+/* $Id: procuid.c,v 1.11 2004/03/04 15:29:16 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,28 +23,20 @@
 
 #include <glibtop.h>
 #include <glibtop/procuid.h>
-
-#define GLIBTOP_PROC_UID_UID		0
-#define GLIBTOP_PROC_UID_EUID		1
-#define GLIBTOP_PROC_UID_GID		2
-#define GLIBTOP_PROC_UID_EGID		3
-#define GLIBTOP_PROC_UID_PID		4
-#define GLIBTOP_PROC_UID_PPID		5
-#define GLIBTOP_PROC_UID_PGRP		6
-#define GLIBTOP_PROC_UID_SESSION	7
-#define GLIBTOP_PROC_UID_TTY		8
-#define GLIBTOP_PROC_UID_TPGID		9
-#define GLIBTOP_PROC_UID_PRIORITY	10
-#define GLIBTOP_PROC_UID_NICE		11
+#include "libgtop-i18n.h"
 
 const char *glibtop_names_proc_uid [GLIBTOP_MAX_PROC_UID] =
 {
-	"uid", "euid", "gid", "egid", "pid", "ppid", "pgrp",
-	"session", "tty", "tpgid", "priority", "nice"
+	"uid", "euid", "gid", "egid", "suid", "sgid", 
+	"fsuid", "fsgid", "pid", "ppid", "pgrp",
+	"session", "tty", "tpgid", "priority", "nice",
+	"ngroups", "groups"
 };
 
 const unsigned glibtop_types_proc_uid [GLIBTOP_MAX_PROC_UID] =
 {
+	GLIBTOP_TYPE_INT, GLIBTOP_TYPE_INT, GLIBTOP_TYPE_INT,
+	GLIBTOP_TYPE_INT, GLIBTOP_TYPE_INT, GLIBTOP_TYPE_INT,
 	GLIBTOP_TYPE_INT, GLIBTOP_TYPE_INT, GLIBTOP_TYPE_INT,
 	GLIBTOP_TYPE_INT, GLIBTOP_TYPE_INT, GLIBTOP_TYPE_INT,
 	GLIBTOP_TYPE_INT, GLIBTOP_TYPE_INT, GLIBTOP_TYPE_INT,
@@ -53,9 +45,10 @@ const unsigned glibtop_types_proc_uid [GLIBTOP_MAX_PROC_UID] =
 
 const char *glibtop_labels_proc_uid [GLIBTOP_MAX_PROC_UID] =
 {
-	N_("Uid"), N_("EUid"), N_("Gid"), N_("EGid"), N_("Pid"),
+	N_("Uid"), N_("EUid"), N_("Gid"), N_("EGid"), N_("SUid"),
+	N_("SGid"), N_("FSUid"), N_("FSGid"), N_("Pid"),
 	N_("PPid"), N_("PGrp"), N_("Session"), N_("Tty"),
-	N_("TPGid"), N_("Priority"), N_("Nice")
+	N_("TPGid"), N_("Priority"), N_("Nice"), N_("NGroups"), N_("Groups")
 };
 
 const char *glibtop_descriptions_proc_uid [GLIBTOP_MAX_PROC_UID] =
@@ -64,6 +57,10 @@ const char *glibtop_descriptions_proc_uid [GLIBTOP_MAX_PROC_UID] =
 	N_("Effective User ID"),
 	N_("Group ID"),
 	N_("Effective Group ID"),
+	N_("Set User ID"),
+	N_("Set Group ID"),
+	N_("Filesystem User ID"),
+	N_("Filesystem Group ID"),
 	N_("Process ID"),
 	N_("PID of parent process"),
 	N_("Process group ID"),
@@ -71,5 +68,7 @@ const char *glibtop_descriptions_proc_uid [GLIBTOP_MAX_PROC_UID] =
 	N_("Full device number of controlling terminal"),
 	N_("Terminal process group ID"),
 	N_("Kernel scheduling priority"),
-	N_("Standard unix nice level of process")
+	N_("Standard unix nice level of process"),
+	N_("Number of additional process groups"),
+	N_("Array of additional process groups")
 };
