@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.14 2003/10/19 16:55:46 carlos Exp $ */
+/* $Id: proclist.c,v 1.16 2003/10/20 15:20:08 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,7 +23,6 @@
 
 #include <glibtop.h>
 #include <glibtop/proclist.h>
-#include <glibtop/xmalloc.h>
 
 #include <sys/stat.h>
 #include <unistd.h>
@@ -97,7 +96,7 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 	      if(s_stat(buffer, &statb) < 0)
 		 return NULL;
 	   }
-	   if(!(pids_chain = glibtop_malloc(sizeof(unsigned))))
+	   if(!(pids_chain = g_malloc(sizeof(unsigned))))
 	      return NULL;
 	   *pids_chain = pid;
 	   return pids_chain;
@@ -189,15 +188,14 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 		 * full, we copy it to the pids_chain. */
 
 		if (count >= BLOCK_COUNT) {
-			/* The following call to glibtop_realloc will be
-			 * equivalent to glibtop_malloc () if `pids_chain' is
+			/* The following call to g_realloc will be
+			 * equivalent to g_malloc () if `pids_chain' is
 			 * NULL. We just calculate the new size and copy `pids'
 			 * to the beginning of the newly allocated block. */
 
 			new_size = pids_size + BLOCK_SIZE;
 
-			pids_chain = glibtop_realloc_r
-				(server, pids_chain, new_size);
+			pids_chain = g_realloc (pids_chain, new_size);
 
 			memcpy (pids_chain + pids_offset, pids, BLOCK_SIZE);
 
@@ -222,14 +220,14 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 
 	if (!count) return NULL;
 
-	/* The following call to glibtop_realloc will be equivalent to
-	 * glibtop_malloc if pids_chain is NULL. We just calculate the
+	/* The following call to g_realloc will be equivalent to
+	 * g_malloc if pids_chain is NULL. We just calculate the
 	 * new size and copy pids to the beginning of the newly allocated
 	 * block. */
 	
 	new_size = pids_size + count * sizeof (unsigned);
 	
-	pids_chain = glibtop_realloc_r (server, pids_chain, new_size);
+	pids_chain = g_realloc (pids_chain, new_size);
 	
 	memcpy (pids_chain + pids_offset, pids, count * sizeof (unsigned));
 	
