@@ -1,4 +1,4 @@
-/* $Id: open.c,v 1.15 2003/10/19 16:55:56 carlos Exp $ */
+/* $Id: open.c,v 1.18 2004/03/09 23:02:06 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,7 +23,6 @@
 
 #include <glibtop.h>
 #include <glibtop/open.h>
-#include <glibtop/xmalloc.h>
 
 struct nlist _glibtop_nlist[] = {
 #ifdef i386
@@ -149,7 +148,7 @@ glibtop_open_p (glibtop *server, const char *program_name,
 	server->machine.ptable_size = (unsigned long) server->machine.nproc *
 		(unsigned long) sizeof (struct proc);
 
-	server->machine.proc_table = glibtop_malloc_r
+	server->machine.proc_table = g_malloc
 		(server, server->machine.ptable_size);
 
 	/* This are for the memory statistics. */
@@ -170,7 +169,7 @@ glibtop_open_p (glibtop *server, const char *program_name,
 		sizeof (struct page);
 
 	server->machine.physpage = (struct page *)
-		glibtop_malloc_r (server, server->machine.bytesize);
+		g_malloc (server->machine.bytesize);
 
 	/* get the page size with "getpagesize" and
 	 * calculate pageshift from it */
