@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: prockernel.c,v 1.13 2003/10/19 16:55:56 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -29,34 +27,34 @@
 #include <glibtop_suid.h>
 
 static const unsigned long _glibtop_sysdeps_proc_kernel =
-(1L << GLIBTOP_PROC_KERNEL_K_FLAGS) + (1L << GLIBTOP_PROC_KERNEL_WCHAN);
+(1 << GLIBTOP_PROC_KERNEL_K_FLAGS) + (1 << GLIBTOP_PROC_KERNEL_WCHAN);
 
 /* Provides detailed information about a process. */
 
-int
+void
 glibtop_get_proc_kernel_p (glibtop *server, glibtop_proc_kernel *buf,
 			   pid_t pid)
 {
-    struct proc *pp;
+	struct proc *pp;
 
-    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_KERNEL), 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_KERNEL), 0);
 
-    memset (buf, 0, sizeof (glibtop_proc_kernel));
+	memset (buf, 0, sizeof (glibtop_proc_kernel));
 
-    /* Read process table from kernel. */	
+	/* Read process table from kernel. */	
 
-    _glibtop_read_proc_table (server);
+	_glibtop_read_proc_table (server);
 
-    /* Find the pid in the process table. */
+	/* Find the pid in the process table. */
 
-    pp = _glibtop_find_pid (server, pid);
+	pp = _glibtop_find_pid (server, pid);
 
-    if (pp == NULL)	return;
+	if (pp == NULL)	return;
 
-    /* Fill in data fields. */
+	/* Fill in data fields. */
 
-    buf->k_flags = pp->p_flag;
-    buf->nwchan = (unsigned long) pp->p_wchan;
+	buf->k_flags = pp->p_flag;
+	buf->nwchan = (unsigned long) pp->p_wchan;
 
-    buf->flags = _glibtop_sysdeps_proc_kernel;
+	buf->flags = _glibtop_sysdeps_proc_kernel;
 }
